--[[--
This is a simple plugin to disable touchscreen on Kindle devices.

@module koplugin.TouchBlock
--]]--

local Dispatcher = require("dispatcher")  -- luacheck:ignore
local InfoMessage = require("ui/widget/infomessage")
local UIManager = require("ui/uimanager")
local WidgetContainer = require("ui/widget/container/widgetcontainer")
local _ = require("gettext")

local TouchBlock = WidgetContainer:new{
    name = "TouchBlock",
    is_doc_only = true,
}

function TouchBlock:onDispatcherRegisterActions()
    Dispatcher:registerAction("touchblock_action", {category="none", event="TouchBlock", title=_("TouchBlock"), general=true,})
end

function TouchBlock:init()
    self:onDispatcherRegisterActions()
    self.ui.menu:registerToMainMenu(self)
end

function TouchBlock:disableTouchscreen()
    os.execute("lipc-set-prop com.lab126.deviced enable_touch 0")
end

function TouchBlock:addToMainMenu(menu_items)
    menu_items.TouchBlock = {
        text = _("Disable Touchscreen"),
        -- in which menu this should be appended
        sorting_hint = "navi",
        -- a callback when tapping
        callback = function()
            UIManager:show(InfoMessage:new{
                text = _("Touchscreen will be disabled untill the next power on. Press any button to dismiss this message."),
                dismiss_callback = self:disableTouchscreen()
            })
        end,
    }
end

return TouchBlock
